<?php
/**
 * Plugin FlashPlayer: Flash Media Player 3.6 in the wiki
 *
 * http://www.jeroenwijering.com/?item=Flash_Media_Player
 * 
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Sam Hall
 */
 
// must be run within Dokuwiki
if(!defined('DOKU_INC')) die();
 
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 
/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_flashplayer extends DokuWiki_Syntax_Plugin {
	var $uid='';
	
    /**
     * return some info
     */
    function getInfo(){
        return array(
            'author' => 'Arno Welzel',
            'email'  => 'himself@arnowelzel.de',
            'date'   => '2009-01-17',
            'name'   => 'FlashPlayer Plugin',
            'desc'   => 'Embeds JW Flash Player 4.3.132 in the page, based on the work of Sam Hall',
        );
    }
 
    function getType(){ return 'formatting'; }
    function getSort(){ return 158; }
    function connectTo($mode) { $this->Lexer->addEntryPattern('<flashplayer.*?>(?=.*?</flashplayer>)',$mode,'plugin_flashplayer'); }
    function postConnect() { $this->Lexer->addExitPattern('</flashplayer>','plugin_flashplayer'); }
 
 
    /**
     * Handle the match
     */
    function handle($match, $state, $pos, &$handler){
        switch ($state) {
            case DOKU_LEXER_ENTER :
                $attributes = strtolower(substr($match, 10, -1));
                $width = $this->_getNumericalAttribute($attributes, "width", "340");
                $height = $this->_getNumericalAttribute($attributes, "height", "20");
				$uid = md5(uniqid(rand(), true));
                return array($state, array($width, $height, $uid));
            case DOKU_LEXER_UNMATCHED :  return array($state, $match);
            case DOKU_LEXER_EXIT :       return array($state, '');
        }
        return array();
    }
 
    /**
     * Create output
     */
    function render($mode, &$renderer, $data) {
        if($mode == 'xhtml'){
            list($state, $vars) = $data;
            switch ($state) {
                case DOKU_LEXER_ENTER :      
					list($width, $height, $this->uid) = $vars;
					
					$renderer->doc .= '</p><p id="flv'.$this->uid.'">('.$this->getLang('getflash').')</p>';
					$renderer->doc .= '<p><script type="text/javascript" defer="defer">';
					$renderer->doc .= 'var s1 = new SWFObject("'.DOKU_BASE.'lib/plugins/flashplayer/player/player.swf","ply","'.$width.'","'.$height.'","9","#FFFFFF");';
					$renderer->doc .= 's1.addParam("allowfullscreen","true");';
					$renderer->doc .= 's1.addParam("allowscriptaccess","always");';
					$renderer->doc .= 's1.addParam("flashvars","';
                    break;
					
                case DOKU_LEXER_UNMATCHED :
					$renderer->doc .= $renderer->_xmlEntities($vars);
					break;
					
                case DOKU_LEXER_EXIT :
					$renderer->doc .= '");';
					$renderer->doc .= 's1.write("flv'.$this->uid.'");';
					$renderer->doc .= '</script>';
					break;
            }
            return true;
        }
        return false;
    }
    
    function _getNumericalAttribute($attributeString, $attribute, $default){
        $retVal = $default;
        $pos = strpos($attributeString, $attribute."=");
        if ($pos === false) {
            //Maybe they have a space...
            $pos = strpos($attributeString, $attribute." ");
        }
        if ($pos > 0) {
            $pos = $pos + strlen($attribute);
            $value = substr($attributeString,$pos);
            
            //replace '=' and quote signs with null and trim leading spaces
            $value = str_replace("=","",$value);
            $value = str_replace("'","",$value);
            $value = str_replace('"','',$value);
            $value = ltrim($value);
            
            //grab the text before the next space
            $pos = strpos($value, " ");
            if ($pos > 0) {
                $value = substr($value,0,$pos);
            }
            
            //validate that it's numerical
            if (preg_match("^[0-9]+$^", $value)) $retVal = $value;
        }
        return $retVal;
    }
}
  
//Setup VIM: ex: et ts=4 enc=utf-8 :